@@ -15,7 +15,8 @@ import cv2 as cv
 import matplotlib.pyplot as plt
 from ansitable import ANSITable, Column
 import spatialmath.base as smb
-from machinevisiontoolbox.base import findpeaks2d
+from machinevisiontoolbox.base import findpeaks2d, draw_circle, draw_line, draw_point, color_bgr
+
 # from machinevisiontoolbox.classes import Image
 
 # from machinevisiontoolbox.Image import *
@@ -77,7 +78,7 @@ class BaseFeature2D:
         :param orient: features have an inherent orientation, defaults to False
         :type orient: bool, optional
 
-        A :class:`BaseFeature2D` object:
+        A :class:`~machinevisiontoolbox.ImagePointFeatures.BaseFeature2D` object:
 
             - has a length, the number of feature points it contains
             - can be sliced to extract a subset of features
@@ -86,7 +87,7 @@ class BaseFeature2D:
         iteration over individual features.  It also supports a number of
         convenience methods.
 
-        .. note:: OpenCV consider feature points as :obj:`opencv.KeyPoint` objects and the
+        :note: OpenCV consider feature points as :obj:`opencv.KeyPoint` objects and the
             descriptors as a multirow NumPy array.  This class provides a more
             convenient abstraction.
         """
@@ -457,7 +458,7 @@ class BaseFeature2D:
             >>> orb[0].id
             >>> orb[:5].id
 
-        .. note:: Defined by the ``id`` attribute of the image passed to the
+        :note: Defined by the ``id`` attribute of the image passed to the
             feature detector
         """
         return [kp.class_id for kp in self._kp]
@@ -567,7 +568,7 @@ class BaseFeature2D:
             >>> orb[0].descriptor
             >>> orb[:5].descriptor.shape
 
-        .. note:: For single feature return a 1D array vector, for multiple features return a set of column vectors.
+        :note: For single feature return a 1D array vector, for multiple features return a set of column vectors.
         """
         return self._descriptor
 
@@ -637,7 +638,7 @@ class BaseFeature2D:
             >>> dist = orb1.distance(orb2)
             >>> dist.shape
 
-        .. note::
+        :note:
             - The matrix is symmetric.
             - For the metric "L1" and "L2" the best match is the smallest distance
             - For the metric "ncc" the best match is the largest distance.  A value over 
@@ -873,7 +874,7 @@ class BaseFeature2D:
             >>> support = orb[0].support(img)
             >>> support
 
-        .. note:: If the features come from multiple images then the feature's
+        :note: If the features come from multiple images then the feature's
             ``id`` attribute is used to index into ``images`` which must be a
             list of Image objects.
         """
@@ -936,7 +937,7 @@ class BaseFeature2D:
             >>> orb2 = orb.filter(minstrength=0.001)
             >>> len(orb2)
 
-        .. note:: If ``value`` is a range the ``numpy.Inf`` or ``-numpy.Inf``
+        :note: If ``value`` is a range the ``numpy.Inf`` or ``-numpy.Inf``
             can be used as values.
         """
 
@@ -1088,7 +1089,7 @@ class BaseFeature2D:
         if filled:
             for kp in self:
                 centre = kp.p.flatten()
-                c = plt.Circle(centre, radius=kp.scale, clip_on=True, **kwargs)
+                c = plt.Circle(centre, radius=kp.scale, clip_on=True, color=color, alpha=alpha, **kwargs)
                 ax.add_patch(c)
                 if hand:
                     circum = centre + kp.scale * np.r_[math.cos(kp.orientation), math.sin(kp.orientation)]
@@ -1101,6 +1102,65 @@ class BaseFeature2D:
 
     #     plt.draw()
 
+    def draw(self, image, *args, ax=None, filled=False, color='blue', alpha=1,
+        hand=False, handcolor='blue', handthickness=1, handalpha=1, **kwargs):
+        """
+        Draw features into image
+
+        :param ax: axes to plot onto, defaults to None
+        :type ax: axes, optional
+        :param filled: shapes are filled, defaults to False
+        :type filled: bool, optional
+        :param hand: draw clock hand to indicate orientation, defaults to False
+        :type hand: bool, optional
+        :param handcolor: color of clock hand, defaults to 'blue'
+        :type handcolor: str, optional
+        :param handthickness: thickness of clock hand in pixels, defaults to 1
+        :type handthickness: int, optional
+        :param handalpha: transparency of clock hand, defaults to 1
+        :type handalpha: int, optional
+        :param kwargs: options passed to :obj:`matplotlib.Circle` such as color,
+            alpha, edgecolor, etc.
+        :type kwargs: dict
+
+        Plot circles to represent the position and scale of features on a Matplotlib axis.
+        Orientation, if applicable, is indicated by a radial line from the circle centre
+        to the circumference, like a clock hand.
+
+        """
+        img = image.image
+        if filled:
+            for kp in self:
+                centre = kp.p.flatten()
+                
+                draw_circle(img, centre, radius=kp.scale, clip_on=True, color=color, alpha=alpha, **kwargs)
+                # draw_circle(img, centre, radius=kp.scale, clip_on=True, color=color, alpha=alpha, **kwargs)
+
+                if hand:
+                    circum = centre + kp.scale * np.r_[math.cos(kp.orientation), math.sin(kp.orientation)]
+                    draw_line(img, (centre[0], circum[0]), (centre[1], circum[1]), color=handcolor, thickness=handthickness, alpha=handalpha)
+        else:
+            if len(args) == 0 and len(kwargs) == 0:
+                kwargs = dict(marker='+y')
+            draw_point(img, self.p, *args, fontsize=0.6, **kwargs)
+    
+    def draw2(self, image, color='y', type='point'):
+        img = image.image
+        if isinstance(color, str):
+            color = color_bgr(color)
+        
+        options = {'rich': cv.DRAW_MATCHES_FLAGS_DRAW_RICH_KEYPOINTS,
+                'point': cv.DRAW_MATCHES_FLAGS_DEFAULT,
+                'not': cv.DRAW_MATCHES_FLAGS_NOT_DRAW_SINGLE_POINTS}
+
+        cv.drawKeypoints(img, # image, source image
+                    self._kp,
+                    img,  # outimage
+                    color=color,
+                    flags=options[type] + cv.DRAW_MATCHES_FLAGS_DRAW_OVER_OUTIMG
+                    )
+
+        return image.__class__(img)
 
 class FeatureMatch:
 
@@ -1129,7 +1189,7 @@ class FeatureMatch:
             - can be sliced to extract a subset of matches
             - inlier/outlier status of matches
         
-        .. note:: This constructor would not be called directly, it is used by the
+        :note: This constructor would not be called directly, it is used by the
             ``match`` method of the :class:`BaseFeature2D` subclass.
 
         :seealso: :obj:`BaseFeature2D.match` `cv2.KeyPoint <https://docs.opencv.org/4.5.2/d2/d29/classcv_1_1KeyPoint.html#a507d41b54805e9ee5042b922e68e4372>`_
@@ -1249,7 +1309,7 @@ class FeatureMatch:
         feature set with specific ``id``. If no such match exists it returns
         None.
 
-        .. note::  
+        :note:  
             - For efficient lookup, on the first call a dict is built that maps
               feature id to index in the feature set.
             - Useful when features in the sets come from multiple images and
@@ -1287,7 +1347,7 @@ class FeatureMatch:
         feature set with specific ``id``. If no such match exists it returns
         None.
 
-        .. note::  
+        :note:  
             - For efficient lookup, on the first call a dict is built that maps
               feature id to index in the feature set.
             - Useful when features in the sets come from multiple images and
@@ -1434,7 +1494,7 @@ class FeatureMatch:
         :return: new match object containing only the inliers
         :rtype: :class:`FeatureMatch` instance
 
-        .. note:: Inlier/outlier status is typically set by some RANSAC-based
+        :note: Inlier/outlier status is typically set by some RANSAC-based
             algorithm that applies a geometric constraint to the sets of
             putative matches.
 
@@ -1480,7 +1540,7 @@ class FeatureMatch:
 
     def plot(self, *pos, darken=False, ax=None, width=None, block=False, **kwargs):
         """
-    Plot matches
+        Plot matches
 
         :param darken: darken the underlying , defaults to False
         :type darken: bool, optional
@@ -1501,7 +1561,7 @@ class FeatureMatch:
 
         combo, u = im1.__class__.Hstack((im1.mono(), im2.mono()), return_offsets=True)
         if ax is None:
-            combo.disp(darken=darken, width=width, block=block)
+            combo.disp(darken=darken, width=width, block=None)
         else:
             plt.sca(ax)
 
@@ -1512,7 +1572,8 @@ class FeatureMatch:
         p1 = self.p1
         p2 = self.p2
         plt.plot((p1[0, :], p2[0, :] + u[1]), (p1[1, :], p2[1, :]), *pos, **kwargs)
-        plt.show(block=block)
+        if plt.isinteractive():
+            plt.show(block=block)
 
     def plot_correspondence(self, *arg, offset=(0,0), **kwargs):
         p1 = self.p1
@@ -1637,6 +1698,50 @@ class FeatureMatch:
         """
         return [self._kp2[m[1]].descriptor for m in self._matches]
 
+    @property
+    @scalar_result
+    def id1(self):
+        """
+        Feature id in first image
+
+        :return: feature id
+        :rtype: int or ndarray(N)
+
+        Example:
+
+        .. runblock:: pycon
+
+            >>> from machinevisiontoolbox import Image
+            >>> orb1 = Image.Read("eiffel-1.png").ORB()
+            >>> orb2 = Image.Read("eiffel-2.png").ORB()
+            >>> matches = orb1.match(orb2)
+            >>> matches.id1
+            >>> matches[0].id1
+        """
+        return [m[0] for m in self._matches]
+
+    @property
+    @scalar_result
+    def id2(self):
+        """
+        Feature id in second image
+
+        :return: feature id
+        :rtype: int or ndarray(N)
+
+        Example:
+
+        .. runblock:: pycon
+
+            >>> from machinevisiontoolbox import Image
+            >>> orb1 = Image.Read("eiffel-1.png").ORB()
+            >>> orb2 = Image.Read("eiffel-2.png").ORB()
+            >>> matches = orb1.match(orb2)
+            >>> matches.id2
+            >>> matches[0].id2
+        """
+        return [m[1] for m in self._matches]
+
 # -------------------- subclasses of BaseFeature2D -------------------------- #
 class SIFTFeature(BaseFeature2D):
     """
@@ -1729,16 +1834,6 @@ class DAISYFeature(BaseFeature2D):
     """
     pass
 
-class FREAKFeature(BaseFeature2D):
-    """
-    Create set of FREAK point features
-
-    .. inheritance-diagram:: machinevisiontoolbox.ImagePointFeatures.FREAKFeature
-        :top-classes: machinevisiontoolbox.ImagePointFeatures.BaseFeature2D
-        :parts: 1
-    """
-    pass
-
 class LATCHFeature(BaseFeature2D):
     """
     Create set of LATCH point features
@@ -1882,7 +1977,7 @@ class ImagePointFeaturesMixin:
             >>> len(orb)  # number of features
             >>> print(orb[:5])
 
-        :seealso: :func:ORBFeature`, `cv2.ORB_create <https://docs.opencv.org/4.5.2/db/d95/classcv_1_1ORB.html>`_
+        :seealso: :class:ORBFeature`, `cv2.ORB_create <https://docs.opencv.org/4.5.2/db/d95/classcv_1_1ORB.html>`_
         """
 
         scoreoptions = {'harris': cv.ORB_HARRIS_SCORE,
@@ -1955,7 +2050,9 @@ class ImagePointFeaturesMixin:
               Pablo F Alcantarilla, Jesús Nuevo, and Adrien Bartoli.
               Trans. Pattern Anal. Machine Intell, 34(7):1281–1298, 2011.
 
-        :seealso: :class:`AKAZEFeature` `cv2.AKAZE <https://docs.opencv.org/4.5.2/d7/d60/classcv_1_1AKAZE.html>`_
+        :seealso: 
+            :class:`~machinevisiontoolbox.ImagePointFeatures.AKAZEFeature`
+            `cv2.AKAZE <https://docs.opencv.org/4.5.2/d7/d60/classcv_1_1AKAZE.html>`_
         """
         return self._image2feature(AKAZEFeature, **kwargs) 
 
@@ -1985,8 +2082,6 @@ class ImagePointFeaturesMixin:
         strength image.  The descriptor is a unit-normalized vector image
         elements in a :math:`w_p \times w_p` patch around the detected feature,
         where :math:`w_p = 2\mathtt{patch}+1`.
-        
-
 
         Returns an iterable and sliceable object that contains Harris features and
         descriptors.
@@ -2149,8 +2244,10 @@ if __name__ == "__main__":
 
     from machinevisiontoolbox import Image, ImageCollection
 
-    kp1 = Image.Read('eiffel-1.png').SIFT()
-    kp2 = Image.Read('eiffel-2.png').SIFT()
+    # kp1 = Image.Read('eiffel-1.png').SIFT()
+    # kp2 = Image.Read('eiffel-2.png').SIFT()
+
+
 
     # kp1 = Image.Read('eiffel2-1.png').Harris()
 
@@ -2159,9 +2256,9 @@ if __name__ == "__main__":
     # d = kp1[0].distance(kp1[30])
     # print(d)
 
-    matches = kp1.match(kp2)
-    matches.subset(10).table()
-    matches.subset(100).plot(linewidth=0.7, darken=False, color="yellow")
+    # matches = kp1.match(kp2)
+    # matches.subset(10).table()
+    # matches.subset(100).plot(linewidth=0.7, darken=False, color="yellow")
 
 
     # c = matches.correspondences()
@@ -2207,7 +2304,26 @@ if __name__ == "__main__":
     # features[:10].table()
 
     im1 = Image.Read("eiffel-1.png", grey=True)
-    im2 = Image.Read("eiffel-2.png", grey=True)
+    # im2 = Image.Read("eiffel-2.png", grey=True)
+
+    sf1 = im1.SIFT(nfeat=200)
+
+    # im1.disp()
+    # sf1.plot()
+    # plt.show(block=True)
+
+    im2 = im1.colorize()
+    sf1.draw2(im2, color='r', type='rich')
+    im2.disp()
+    plt.show(block=True)
+
+    # im3 = im1.colorize()
+    # z = sf1.drawKeypoints(im3)
+    # im3.disp(block=True)
+
+
+
+    plt.show(block=True)
 
     # hf1 = im1.Harris(nfeat=250, scale=10)
     # print(hf1[5])
